# Abstract

ViewSet.pk, which describes how to parse the primary key of the model in a url pattern, 
needs to be set manually for each ViewSet.

# Tasks

- Auto discover the pk from the ViewSet.model
- manual override must be possible
- update documentation
- update tests
- update examples
 